@@ -15,8 +15,8 @@ class Analytical:
 
     def __init__(
         self,
-        read_params: Dict[str, dict],
-        write_params: Dict[str, dict],
+        read_params: dict,
+        write_params: dict,
         aggregation_function,
         date: datetime,
         aws_interface: AWSInterface,
@@ -38,7 +38,7 @@ class Analytical:
             "spark": spark_manager.spark,
             "aws_interface": aws_interface,
             "date": date,
-            "session_name": "analytical_tables"
+            "session_name": "analytical_tables",
         }
         # Set up logging
         self.logger = logging.getLogger(__name__)
@@ -46,12 +46,12 @@ class Analytical:
 
     @staticmethod
     def _init_tables(
-        params: Dict[str, dict],
+        params: dict,
         date: datetime,
         aws_interface: AWSInterface,
         spark_manager: SparkManager,
         overwrite: bool,
-    ) -> Dict[str, Table]:
+    ) -> dict:
         """
         Initialize the tables for data read and write operations.
         """
@@ -75,7 +75,8 @@ class Analytical:
         self.logger.info("Preparing inputs...")
         try:
             self.inputs = {
-                table_name: {"df": table.read_table()} for table_name, table in self.read.items()
+                table_name: {"df": table.read_table()}
+                for table_name, table in self.read.items()
             }
             self.logger.debug(f"Prepared inputs: {self.inputs}")
         except Exception as e:
@@ -92,7 +93,7 @@ class Analytical:
             self.prepare_inputs()
             # print("\ninputs: ", self.inputs, "\n")
             # print("\nagg:", self.aggregation_function, "\n")
-            self.output = self.aggregation_function(inputs=self.inputs, meta = self.meta)
+            self.output = self.aggregation_function(inputs=self.inputs, meta=self.meta)
             self.logger.debug(f"Aggregation output: {self.output}")
             # print("\noutput2: ", self.output, "\n")
             for table_name, table in self.write.items():
